@@ -575,8 +575,8 @@ globus_i_gsi_gss_create_and_fill_context(
     }
 #endif
 
-    /* No longer setting SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS since it seemed
-     * like a stop-gap measure to interoperate with broken SSL */
+    /* This is needed for compatibility with Bestman */
+    SSL_set_options(context->gss_ssl, SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS);
 
     local_result = globus_gsi_callback_get_SSL_callback_data_index(&cb_index);
     if(local_result != GLOBUS_SUCCESS)
@@ -2322,11 +2322,14 @@ globus_i_gsi_gssapi_init_ssl_context(
      * and require TLS for all secure communication." */
     GLOBUS_I_GSI_GSSAPI_DEBUG_PRINT(
         2, "Disabling SSLv2 and SSLv3.\n");
-    /* Minimum version allowed is TLS 1.0 */
+    /* Default minimum version is TLS 1.2 as of August 2018 */
     if (globus_i_gsi_gssapi_min_tls_protocol == 0)
-        globus_i_gsi_gssapi_min_tls_protocol = TLS1_VERSION;
+        globus_i_gsi_gssapi_min_tls_protocol = TLS1_2_VERSION;
     if (globus_i_gsi_gssapi_max_tls_protocol == 0)
-        globus_i_gsi_gssapi_max_tls_protocol = TLS_MAX_VERSION;
+        /* The GSI GSSAPI currently does not work with TLS 1.3
+           Use TLS1_2_VERSION instead of TLS_MAX_VERSION as the maximum TLS
+           protocol version until it has been ported */
+        globus_i_gsi_gssapi_max_tls_protocol = TLS1_2_VERSION;
     GLOBUS_I_GSI_GSSAPI_DEBUG_FPRINTF(
         3, (globus_i_gsi_gssapi_debug_fstream,
         "MIN_TLS_PROTOCOL: %x\n", globus_i_gsi_gssapi_min_tls_protocol));
